@@ -1,3 +1,5 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+
 /* 
  *   Gnome Nibbles: Gnome Worm Game
  *   Written by Sean MacIsaac <sjm@acm.org>, Ian Peters <itp@gnu.org>
@@ -37,7 +39,8 @@ extern GnibblesProperties *properties;
 
 extern gint current_level;
 
-GnibblesWorm *gnibbles_worm_new (guint t_number)
+GnibblesWorm *
+gnibbles_worm_new (guint t_number)
 {
         GnibblesWorm *tmp = (GnibblesWorm *) g_malloc (sizeof (GnibblesWorm));
 
@@ -50,15 +53,17 @@ GnibblesWorm *gnibbles_worm_new (guint t_number)
         return tmp;
 }
 
-void gnibbles_worm_destroy (GnibblesWorm *worm)
+void 
+gnibbles_worm_destroy (GnibblesWorm *worm)
 {
 	free (worm->xoff);
 	free (worm->yoff);
 	free (worm);
 }
 
-void gnibbles_worm_set_start (GnibblesWorm *worm, guint t_xhead, guint t_yhead,
-		gint t_direction)
+void 
+gnibbles_worm_set_start (GnibblesWorm *worm, guint t_xhead, guint t_yhead,
+			 gint t_direction)
 {
 	worm->xhead = t_xhead;
 	worm->yhead = t_yhead;
@@ -74,45 +79,58 @@ void gnibbles_worm_set_start (GnibblesWorm *worm, guint t_xhead, guint t_yhead,
 	worm->keypress = 0;
 }
 
-void gnibbles_worm_handle_keypress (GnibblesWorm *worm, guint keyval)
+gint
+gnibbles_worm_handle_keypress (GnibblesWorm *worm, guint keyval)
 {
+	gint key_left, key_right, key_up, key_down;
+
 	if (worm->keypress)
-		return;
+		return FALSE;
+
+	key_left = gdk_keyval_from_name (properties->wormprops[worm->number]->left);
+	key_right = gdk_keyval_from_name (properties->wormprops[worm->number]->right);
+	key_up = gdk_keyval_from_name (properties->wormprops[worm->number]->up);
+	key_down = gdk_keyval_from_name (properties->wormprops[worm->number]->down);
 	
 	if (properties->wormprops[worm->number]->relmove) {
-		if (keyval == properties->wormprops[worm->number]->left)
+		if (keyval == key_left)
 			worm->direction = worm->direction - 1;
-		if (keyval == properties->wormprops[worm->number]->right)
+		else if (keyval == key_right)
 			worm->direction = worm->direction + 1;
+                else
+                        return FALSE;
 		if (worm->direction == 0)
 			worm->direction = 4;
 		if (worm->direction == 5)
 			worm->direction = 1;
+                return TRUE;
 	} else {
-		if ((keyval == properties->wormprops[worm->number]->up) &&
-				(worm->direction != WORMDOWN)) {
+		if ((keyval == key_up) && (worm->direction != WORMDOWN)) {
 			worm->direction = WORMUP;
 			worm->keypress = 1;
+                        return TRUE;
 		}
-		if ((keyval == properties->wormprops[worm->number]->right) &&
-				(worm->direction !=WORMLEFT)) {
+		if ((keyval == key_right) && (worm->direction !=WORMLEFT)) {
 			worm->direction = WORMRIGHT;
 			worm->keypress = 1;
+                        return TRUE;
 		}
-		if ((keyval == properties->wormprops[worm->number]->down) &&
-				(worm->direction != WORMUP)) {
+		if ((keyval == key_down) && (worm->direction != WORMUP)) {
 			worm->direction = WORMDOWN;
 			worm->keypress = 1;
+                        return TRUE;
 		}
-		if ((keyval == properties->wormprops[worm->number]->left) &&
-				(worm->direction != WORMRIGHT)) {
+		if ((keyval == key_left) && (worm->direction != WORMRIGHT)) {
 			worm->direction = WORMLEFT;
 			worm->keypress = 1;
+                        return TRUE;
 		}
 	}
+        return FALSE;
 }
 
-static gint gnibbles_worm_reverse (gpointer data)
+static gint
+gnibbles_worm_reverse (gpointer data)
 {
 	gint i, j, temp;
 	GnibblesWorm *worm;
@@ -153,7 +171,8 @@ static gint gnibbles_worm_reverse (gpointer data)
 	return FALSE;
 }
 
-static void gnibbles_worm_grok_bonus (GnibblesWorm *worm)
+static void
+gnibbles_worm_grok_bonus (GnibblesWorm *worm)
 {
 	int i;
 
@@ -193,15 +212,16 @@ static void gnibbles_worm_grok_bonus (GnibblesWorm *worm)
 		case BONUSREVERSE:
 			for (i = 0; i < properties->numworms; i++)
 				if (worm != worms[i])
-					gtk_timeout_add(1, (GtkFunction)
-							gnibbles_worm_reverse,
-						 	worms[i]);
+					gtk_timeout_add (1, (GtkFunction)
+							 gnibbles_worm_reverse,
+							 worms[i]);
 			gnibbles_play_sound ("reverse");
 			break;
 	}
 }
 
-void gnibbles_worm_draw_head (GnibblesWorm *worm)
+void
+gnibbles_worm_draw_head (GnibblesWorm *worm)
 {
 	worm->keypress = 0;
 	
@@ -276,7 +296,8 @@ void gnibbles_worm_draw_head (GnibblesWorm *worm)
 			worm->xhead, worm->yhead);
 }
 
-gint gnibbles_worm_test_move_head(GnibblesWorm *worm)
+gint
+gnibbles_worm_test_move_head(GnibblesWorm *worm)
 {
 	int x, y;
 
@@ -317,7 +338,8 @@ gint gnibbles_worm_test_move_head(GnibblesWorm *worm)
 	return (TRUE);
 }
 
-void gnibbles_worm_erase_tail (GnibblesWorm *worm)
+void
+gnibbles_worm_erase_tail (GnibblesWorm *worm)
 {
 	if (worm->change <= 0) {
 		board[worm->xtail][worm->ytail] = EMPTYCHAR;
@@ -329,7 +351,8 @@ void gnibbles_worm_erase_tail (GnibblesWorm *worm)
 	}
 }
 
-void gnibbles_worm_move_tail (GnibblesWorm *worm)
+void
+gnibbles_worm_move_tail (GnibblesWorm *worm)
 {
 	if (worm->change <= 0) {
 		gnibbles_draw_pixmap (BLANKPIXMAP, worm->xtail, worm->ytail);
@@ -356,7 +379,8 @@ void gnibbles_worm_move_tail (GnibblesWorm *worm)
 	}
 }
 
-gint gnibbles_worm_lose_life (GnibblesWorm *worm)
+gint
+gnibbles_worm_lose_life (GnibblesWorm *worm)
 {
 	worm->lives--;
 	if (worm->lives < 0)
@@ -365,7 +389,8 @@ gint gnibbles_worm_lose_life (GnibblesWorm *worm)
 	return 0;
 }
 
-void gnibbles_worm_undraw_nth (GnibblesWorm *worm, gint offset)
+void
+gnibbles_worm_undraw_nth (GnibblesWorm *worm, gint offset)
 {
 	int x, y, i, j;
 
